from setuptools import setup, find_packages

setup(
    name='MaFx',
    version='0.0.1.1',
    packages=find_packages(),
    description='A Complex Math Library',
    long_description=open('README.md').read(),
    license='MIT',
    author='FedxD',
    author_email="abbaskazim135@gmail.com",
)